@@ -208,7 +208,7 @@ class Bitpin:
 
         self._raise_for_exception(func_name, response, additional)
         if response.request.method.lower() == 'delete':
-            return {}
+            return {'success': True}
         return response.json()
 
     def __request(
